Crate neopdf_capi

Crate neopdf_capi 

The C-language interface for NeoPDF

Structs

NeoPDFGrid
An opaque struct holding the data for a single grid, including its subgrids and flavors. C code should not access its fields directly.
NeoPDFGridArrayCollection
Represents a dynamically-sized collection of NeoPDFGrid pointers. This struct is exposed to C and manages memory for the array of pointers.
NeoPDFLazyIterator
Opaque pointer to a lazy PDF iterator object.
NeoPDFMembers
Structure to hold an array of PDF pointers and its length.
NeoPDFMetaData
Metadata for PDF grids
NeoPDFMetaDataV2
Metadata for PDF grids (V2 with extended fields)
NeoPDFPhysicsParameters
Physical Parameters of the PDF set.
NeoPDFWrapper
Opaque pointer to a PDF object.

Enums

NeopdfResult
Result codes for NeoPDF operations
NeopdfSubgridParams
Parameters for subgrids in the PDF grid.

Functions

alphaspdf
Evaluates the strong coupling alpha_s at scale q for the active member.
alphaspdf_
Fortran name-mangled variant of alphaspdf.
evolvepdf
Evaluates parton distribution functions at given (x, q) for the active member.
evolvepdf_
Fortran name-mangled variant of evolvepdf.
initpdf
Selects the active member of the currently loaded PDF set.
initpdf_
Fortran name-mangled variant of initpdf.
initpdfsetbyname
Initializes a PDF set by its name/path and loads all members.
initpdfsetbyname_
Fortran name-mangled variant of initpdfsetbyname.
neopdf_grid_add_subgrid
Adds a subgrid to an existing NeoPDFGrid.
neopdf_grid_add_subgridv2
Adds a subgrid to an existing NeoPDFGrid (v2 for 8D).
neopdf_grid_compress
Compresses a collection of NeoPDFGrid objects and writes them to a file.
neopdf_grid_compress_v2
Compresses a collection of NeoPDFGrid objects and writes them to a file (V2).
neopdf_grid_free
Frees the memory allocated for a NeoPDFGrid.
neopdf_grid_new
Creates a new, empty NeoPDFGrid.
neopdf_grid_set_flavors
Sets the flavor IDs for a NeoPDFGrid.
neopdf_gridarray_collection_add_grid
Adds a NeoPDFGrid to a NeoPDFGridArrayCollection.
neopdf_gridarray_collection_free
Frees the memory of a NeoPDFGridArrayCollection and all the grids it contains.
neopdf_gridarray_collection_new
Creates a new, empty NeoPDFGridArrayCollection.
neopdf_lazy_iterator_free
Frees a lazy PDF iterator object.
neopdf_lazy_iterator_next
Retrieves the next PDF member from the lazy iterator.
neopdf_pdf_alphas_q2
Computes the alpha_s value at a given Q2.
neopdf_pdf_array_free
Frees the memory allocated for a NeoPDFMembers.
neopdf_pdf_free
Frees a PDF object.
neopdf_pdf_is_force_positive
Returns the value of ForcePositive defining the PDF grid.
neopdf_pdf_load
Loads a given member of the PDF set.
neopdf_pdf_load_all
Loads all members of the PDF set.
neopdf_pdf_load_by_lhaid
Loads a PDF member by its LHAPDF ID (LHAID).
neopdf_pdf_load_lazy
Loads a PDF set for lazy iteration.
neopdf_pdf_load_lhapdf_by_file
Loads a PDF member from a specific LHAPDF .dat file path.
neopdf_pdf_num_pids
Returns the number of PIDs.
neopdf_pdf_num_subgrids
Returns the number of subgrids in the PDF Grid.
neopdf_pdf_param_range
Returns the minimum and maximum value for a given parameter.
neopdf_pdf_pids
Returns the PID representation of the PDF Grid.
neopdf_pdf_q2_max
Retrieves the q2_max for this PDF set.
neopdf_pdf_q2_min
Retrieves the q2_min for this PDF set.
neopdf_pdf_set_force_positive
Clip the interpolated values if they turned out negatives.
neopdf_pdf_set_force_positive_members
Clip the interpolated values if they turned out negatives for all members.
neopdf_pdf_subgrids_for_param
Returns the grid values of a parameter for a given subgrid.
neopdf_pdf_subgrids_shape_for_param
Returns the shape of the subgrids in the order of their index for a given parameter.
neopdf_pdf_x_max
Retrieves the x_max for this PDF set.
neopdf_pdf_x_min
Retrieves the x_min for this PDF set.
neopdf_pdf_xfxq2
Interpolates the PDF value (xf) for a given flavor, x, and Q2.
neopdf_pdf_xfxq2_cheby_batch
Interpolates PDF values for multiple points in parallel using Chebyshev batch interpolation.
neopdf_pdf_xfxq2_nd
Interpolates the PDF value (xf) for a generic set of parameters.
neopdf_pdf_xfxq2_pids
Evaluates all requested flavors at a single kinematic point.
neopdf_pdf_xfxq2s
Interpolates PDF values for multiple PIDs at multiple kinematic points.
setlhaparm
Sets LHAPDF runtime parameters from a string (no-op).
setlhaparm_
Fortran name-mangled variant of setlhaparm (no-op).