The C-language interface for NeoPDF
Structs
- NeoPDF
Grid - An opaque struct holding the data for a single grid, including its subgrids and flavors. C code should not access its fields directly.
- NeoPDF
Grid Array Collection - Represents a dynamically-sized collection of
NeoPDFGridpointers. This struct is exposed to C and manages memory for the array of pointers. - NeoPDF
Lazy Iterator - Opaque pointer to a lazy PDF iterator object.
- NeoPDF
Members - Structure to hold an array of PDF pointers and its length.
- NeoPDF
Meta Data - Metadata for PDF grids
- NeoPDF
Meta Data V2 - Metadata for PDF grids (V2 with extended fields)
- NeoPDF
Physics Parameters - Physical Parameters of the PDF set.
- NeoPDF
Wrapper - Opaque pointer to a PDF object.
Enums
- Neopdf
Result - Result codes for
NeoPDFoperations - Neopdf
Subgrid Params - Parameters for subgrids in the PDF grid.
Functions
- alphaspdf⚠
- Evaluates the strong coupling
alpha_sat scaleqfor the active member. - alphaspdf_⚠
- Fortran name-mangled variant of
alphaspdf. - evolvepdf⚠
- Evaluates parton distribution functions at given
(x, q)for the active member. - evolvepdf_⚠
- Fortran name-mangled variant of
evolvepdf. - initpdf⚠
- Selects the active member of the currently loaded PDF set.
- initpdf_⚠
- Fortran name-mangled variant of
initpdf. - initpdfsetbyname⚠
- Initializes a PDF set by its name/path and loads all members.
- initpdfsetbyname_⚠
- Fortran name-mangled variant of
initpdfsetbyname. - neopdf_
grid_ ⚠add_ subgrid - Adds a subgrid to an existing
NeoPDFGrid. - neopdf_
grid_ ⚠add_ subgridv2 - Adds a subgrid to an existing
NeoPDFGrid(v2 for 8D). - neopdf_
grid_ ⚠compress - Compresses a collection of
NeoPDFGridobjects and writes them to a file. - neopdf_
grid_ ⚠compress_ v2 - Compresses a collection of
NeoPDFGridobjects and writes them to a file (V2). - neopdf_
grid_ ⚠free - Frees the memory allocated for a
NeoPDFGrid. - neopdf_
grid_ new - Creates a new, empty
NeoPDFGrid. - neopdf_
grid_ ⚠set_ flavors - Sets the flavor IDs for a
NeoPDFGrid. - neopdf_
gridarray_ ⚠collection_ add_ grid - Adds a
NeoPDFGridto aNeoPDFGridArrayCollection. - neopdf_
gridarray_ ⚠collection_ free - Frees the memory of a
NeoPDFGridArrayCollectionand all the grids it contains. - neopdf_
gridarray_ collection_ new - Creates a new, empty
NeoPDFGridArrayCollection. - neopdf_
lazy_ ⚠iterator_ free - Frees a lazy PDF iterator object.
- neopdf_
lazy_ ⚠iterator_ next - Retrieves the next PDF member from the lazy iterator.
- neopdf_
pdf_ ⚠alphas_ q2 - Computes the
alpha_svalue at a given Q2. - neopdf_
pdf_ ⚠array_ free - Frees the memory allocated for a
NeoPDFMembers. - neopdf_
pdf_ ⚠free - Frees a PDF object.
- neopdf_
pdf_ ⚠is_ force_ positive - Returns the value of
ForcePositivedefining the PDF grid. - neopdf_
pdf_ ⚠load - Loads a given member of the PDF set.
- neopdf_
pdf_ ⚠load_ all - Loads all members of the PDF set.
- neopdf_
pdf_ load_ by_ lhaid - Loads a PDF member by its LHAPDF ID (LHAID).
- neopdf_
pdf_ ⚠load_ lazy - Loads a PDF set for lazy iteration.
- neopdf_
pdf_ ⚠load_ lhapdf_ by_ file - Loads a PDF member from a specific LHAPDF
.datfile path. - neopdf_
pdf_ ⚠num_ pids - Returns the number of PIDs.
- neopdf_
pdf_ ⚠num_ subgrids - Returns the number of subgrids in the PDF Grid.
- neopdf_
pdf_ ⚠param_ range - Returns the minimum and maximum value for a given parameter.
- neopdf_
pdf_ ⚠pids - Returns the PID representation of the PDF Grid.
- neopdf_
pdf_ ⚠q2_ max - Retrieves the
q2_maxfor this PDF set. - neopdf_
pdf_ ⚠q2_ min - Retrieves the
q2_minfor this PDF set. - neopdf_
pdf_ ⚠set_ force_ positive - Clip the interpolated values if they turned out negatives.
- neopdf_
pdf_ ⚠set_ force_ positive_ members - Clip the interpolated values if they turned out negatives for all members.
- neopdf_
pdf_ ⚠subgrids_ for_ param - Returns the grid values of a parameter for a given subgrid.
- neopdf_
pdf_ ⚠subgrids_ shape_ for_ param - Returns the shape of the subgrids in the order of their index for a given parameter.
- neopdf_
pdf_ ⚠x_ max - Retrieves the
x_maxfor this PDF set. - neopdf_
pdf_ ⚠x_ min - Retrieves the
x_minfor this PDF set. - neopdf_
pdf_ ⚠xfxq2 - Interpolates the PDF value (xf) for a given flavor, x, and Q2.
- neopdf_
pdf_ ⚠xfxq2_ cheby_ batch - Interpolates PDF values for multiple points in parallel using Chebyshev batch interpolation.
- neopdf_
pdf_ ⚠xfxq2_ nd - Interpolates the PDF value (xf) for a generic set of parameters.
- neopdf_
pdf_ ⚠xfxq2_ pids - Evaluates all requested flavors at a single kinematic point.
- neopdf_
pdf_ ⚠xfxq2s - Interpolates PDF values for multiple PIDs at multiple kinematic points.
- setlhaparm⚠
- Sets LHAPDF runtime parameters from a string (no-op).
- setlhaparm_⚠
- Fortran name-mangled variant of
setlhaparm(no-op).